Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: Source/modules/storage/StorageArea.cpp

Issue 1026253002: Rename FrameDestructionObserver to LocalFrameLifecycleObserver. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: rebased Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/storage/StorageArea.h ('k') | Source/web/WebPluginContainerImpl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/modules/storage/StorageArea.cpp
diff --git a/Source/modules/storage/StorageArea.cpp b/Source/modules/storage/StorageArea.cpp
index fca4930738a398961877c2b45dda8dd443cce7c6..c8be9f14708df8ed125074e8d5805fb6ac2c764b 100644
--- a/Source/modules/storage/StorageArea.cpp
+++ b/Source/modules/storage/StorageArea.cpp
@@ -53,7 +53,7 @@ PassOwnPtrWillBeRawPtr<StorageArea> StorageArea::create(PassOwnPtr<WebStorageAre
}
StorageArea::StorageArea(PassOwnPtr<WebStorageArea> storageArea, StorageType storageType)
- : FrameDestructionObserver(nullptr)
+ : LocalFrameLifecycleObserver(nullptr)
, m_storageArea(storageArea)
, m_storageType(storageType)
, m_canAccessStorageCachedResult(false)
@@ -66,7 +66,7 @@ StorageArea::~StorageArea()
DEFINE_TRACE(StorageArea)
{
- FrameDestructionObserver::trace(visitor);
+ LocalFrameLifecycleObserver::trace(visitor);
}
unsigned StorageArea::length(ExceptionState& exceptionState, LocalFrame* frame)
@@ -140,7 +140,7 @@ bool StorageArea::canAccessStorage(LocalFrame* frame)
if (!frame || !frame->page())
return false;
// FrameDestructionObserver is used to safely keep the cached
// reference to the LocalFrame. Should the LocalFrame die before
// this StorageArea does, that cached reference will be cleared.
if (this->frame() == frame)
@@ -150,7 +150,7 @@ bool StorageArea::canAccessStorage(LocalFrame* frame)
return false;
bool result = controller->storageClient()->canAccessStorage(frame, m_storageType);
// Move attention to the new LocalFrame.
- FrameDestructionObserver::setContext(frame);
+ LocalFrameLifecycleObserver::setContext(frame);
m_canAccessStorageCachedResult = result;
return result;
}
@@ -140,7 +140,7 @@ bool StorageArea::canAccessStorage(LocalFrame* frame)
if (!frame || !frame->page())
return false;
- // FrameDestructionObserver is used to safely keep the cached
+ // LocalFrameLifecycleObserver is used to safely keep the cached
// reference to the LocalFrame. Should the LocalFrame die before
// this StorageArea does, that cached reference will be cleared.
« no previous file with comments | « Source/modules/storage/StorageArea.h ('k') | Source/web/WebPluginContainerImpl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698